fbchat\_muqit.Message
=====================

.. currentmodule:: fbchat_muqit

.. autoclass:: Message

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Message.__copy__
      ~Message.__delattr__
      ~Message.__dir__
      ~Message.__eq__
      ~Message.__format__
      ~Message.__ge__
      ~Message.__getattribute__
      ~Message.__getstate__
      ~Message.__gt__
      ~Message.__hash__
      ~Message.__init__
      ~Message.__init_subclass__
      ~Message.__le__
      ~Message.__lt__
      ~Message.__ne__
      ~Message.__new__
      ~Message.__reduce__
      ~Message.__reduce_ex__
      ~Message.__replace__
      ~Message.__repr__
      ~Message.__rich_repr__
      ~Message.__setattr__
      ~Message.__sizeof__
      ~Message.__str__
      ~Message.__subclasshook__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Message.attachments
      ~Message.can_unsend
      ~Message.id
      ~Message.mentions
      ~Message.message_type
      ~Message.reaction
      ~Message.replied_to_message
      ~Message.replied_to_message_id
      ~Message.sender_id
      ~Message.text
      ~Message.thread_folder
      ~Message.thread_id
      ~Message.thread_participants
      ~Message.thread_type
      ~Message.timestamp
      ~Message.unsent
      ~Message.__annotations__
      ~Message.__doc__
      ~Message.__module__
      ~Message.__slots__
      ~Message.__struct_config__
      ~Message.__struct_defaults__
      ~Message.__struct_encode_fields__
      ~Message.__struct_fields__
   
   